rlrt.mp(Y, x = NULL, loginvsp, nbasis = 15, norder = 4, nulldim = NULL,
evalarg = NULL, get.df = FALSE, B = NULL, P = NULL)fd".Y is of class "fd", the argument values at which the functions are evaluated.table for each test.get.df = TRUE, the effective degrees of freedom corresponding to the log smoothing parameter values in logsp.rlrt4d, and Fdr.rlrt for a more sophisticated false discovery rate procedure.Y = matrix(rnorm(6000), nrow=20)
x = rnorm(20)
t4 = rlrt.mp(Y, x, loginvsp = -22:0)
f4 = Fdr.rlrt(t4, 6)Run the code above in your browser using DataLab