rlrt.mp.fit(Y, X, Z, loginvsp, evalarg = NULL, get.df = FALSE)Y is of class "fd", the argument values at which the functions are evaluated.table for each test.get.df = TRUE, the effective degrees of freedom corresponding to the log smoothing parameter values in logsp.Y = matrix(rnorm(6000), nrow=20)
x = rnorm(20)
z = rep(1:5, each = 4)
t4. = rlrt.mp.fit(Y, x, z, loginvsp = -22:0)Run the code above in your browser using DataLab