Learn R Programming

vows (version 0.3.1)

rlrt.mp: Massively parallel restricted likelihood ratio tests

Description

Conducts a possibly very large number of restricted likelihood ratio tests (Crainiceanu and Ruppert, 2004), with common design matrix, for a polynomial null against a smooth alternative.

Usage

rlrt.mp(Y, x = NULL, loginvsp, nbasis = 15, norder = 4, nulldim = NULL,
  evalarg = NULL, get.df = FALSE, B = NULL, P = NULL)

Arguments

Y
ordinarily, an $n \times V$ outcome matrix, where $V$ is the number of hypotheses (in brain imaging applications, the number of voxels). Can also be given by an object of class "fd".
x
a vector or matrix of covariates.
nbasis
number of B-spline basis functions.
norder
order of B-splines.
nulldim
dimension of the null space of the penalty.
loginvsp
a grid of candidate values of the log inverse smoothing parameter.
evalarg
if Y is of class "fd", the argument values at which the functions are evaluated.
get.df
logical: Should the effective df of the smooth at each point be obtained?
B
evaluation matrix of the B-spline basis functions.
P
penalty matrix.

Value

  • A list with components
  • tablematrix of log restricted likelihood ratio values at each grid point, for each test.
  • statRLRT statistics, i.e., the supremum of the values in table for each test.
  • logsplog smoothing parameter at which the supremum of the restricted likelihood ratio is attained for each test.
  • dfif get.df = TRUE, the effective degrees of freedom corresponding to the log smoothing parameter values in logsp.
  • simvalues simulated from the null distribution of the restricted likelihood ratio statistic.
  • pvaluep-values for the RLRT statistics.
  • fdrBenjamini-Hochberg false discovery rates corresponding to the above p-values.
  • callthe call to the function.

Details

The RLRsim package of Scheipl et al. (2008) is used to simulate the common null distribution of the RLRT statistics.

References

Crainiceanu, C. M., and Ruppert, D. (2004). Likelihood ratio tests in linear mixed models with one variance component. Journal of the Royal Statistical Society, Series B, 66(1), 165--185.

Reiss, P. T., Huang, L., Chen, Y.-H., Huo, L., Tarpey, T., and Mennes, M. (2014). Massively parallel nonparametric regression, with an application to developmental brain mapping. Journal of Computational and Graphical Statistics, Journal of Computational and Graphical Statistics, 23(1), 232--248.

Scheipl, F., Greven, S. and Kuechenhoff, H. (2008). Size and power of tests for a zero random effect variance or polynomial regression in additive and linear mixed models. Computational Statistics & Data Analysis, 52(7), 3283--3299.

See Also

rlrt4d, and Fdr.rlrt for a more sophisticated false discovery rate procedure.

Examples

Run this code
Y = matrix(rnorm(6000), nrow=20)
x = rnorm(20)
t4 = rlrt.mp(Y, x, loginvsp = -22:0)
f4 = Fdr.rlrt(t4, 6)

Run the code above in your browser using DataLab