rlrt.mp.fit(Y, X, Z, loginvsp, evalarg = NULL, get.df = FALSE)Y is of class "fd", the argument values at which
the functions are evaluated.table for each test.get.df =
TRUE, the effective degrees of freedom corresponding to the log smoothing
parameter values in logsp.Scheipl, F., Greven, S. and Kuechenhoff, H. (2008). Size and power of tests for a zero random effect variance or polynomial regression in additive and linear mixed models. Computational Statistics & Data Analysis, 52(7), 3283--3299.
Y = matrix(rnorm(6000), nrow=20)
x = rnorm(20)
z = rep(1:5, each = 4)
t4. = rlrt.mp.fit(Y, x, z, loginvsp = -22:0)
Run the code above in your browser using DataLab